Module files_api

Module files_api 

Enums

CreateFileError
struct for typed errors of method create_file
CreateFileVersionError
struct for typed errors of method create_file_version
DeleteFileError
struct for typed errors of method delete_file
DeleteFileVersionError
struct for typed errors of method delete_file_version
DownloadFileVersionError
struct for typed errors of method download_file_version
FinishFileDataUploadError
struct for typed errors of method finish_file_data_upload
GetAdminAssetBundleError
struct for typed errors of method get_admin_asset_bundle
GetContentAgreementStatusError
struct for typed errors of method get_content_agreement_status
GetFileAnalysisError
struct for typed errors of method get_file_analysis
GetFileAnalysisSecurityError
struct for typed errors of method get_file_analysis_security
GetFileAnalysisStandardError
struct for typed errors of method get_file_analysis_standard
GetFileDataUploadStatusError
struct for typed errors of method get_file_data_upload_status
GetFileError
struct for typed errors of method get_file
GetFilesError
struct for typed errors of method get_files
SetGroupGalleryFileOrderError
struct for typed errors of method set_group_gallery_file_order
StartFileDataUploadError
struct for typed errors of method start_file_data_upload
SubmitContentAgreementError
struct for typed errors of method submit_content_agreement
UpdateAssetReviewNotesError
struct for typed errors of method update_asset_review_notes
UploadGalleryImageError
struct for typed errors of method upload_gallery_image
UploadIconError
struct for typed errors of method upload_icon
UploadImageError
struct for typed errors of method upload_image

Functions

create_file
Creates a new File object
create_file_version
Creates a new FileVersion. Once a Version has been created, proceed to the /file/{fileId}/{versionId}/file/start endpoint to start a file upload.
delete_file
Deletes a File object.
delete_file_version
Delete a specific version of a file. You can only delete the latest version.
download_file_version
Downloads the file with the provided version number. Version Note: Version 0 is always when the file was created. The real data is usually always located in version 1 and up. Extension Note: Files are not guaranteed to have a file extensions. UnityPackage files tends to have it, images through this endpoint do not. You are responsible for appending file extension from the extension field when neccesary.
finish_file_data_upload
Finish an upload of a FileData. This will mark it as "complete". After uploading the file for Avatars and Worlds you then have to upload a signature file.
get_admin_asset_bundle
Returns an AdminAssetBundle
get_content_agreement_status
Returns the agreement status of the currently authenticated user for the given agreementCode, contentId, and version.
get_file
Shows general information about the "File" object. Each File can have several "Version"’s, and each Version can have multiple real files or "Data" blobs.
get_file_analysis
Get the performance analysis for the uploaded assets of an avatar
get_file_analysis_security
Get the security performance analysis for the uploaded assets of an avatar
get_file_analysis_standard
Get the standard performance analysis for the uploaded assets of an avatar
get_file_data_upload_status
Retrieves the upload status for file upload. Can currently only be accessed when status is waiting. Trying to access it on a file version already uploaded currently times out.
get_files
Returns a list of files
set_group_gallery_file_order
Set the order of the files in a group gallery
start_file_data_upload
Starts an upload of a specific FilePart. This endpoint will return an AWS URL which you can PUT data to. You need to call this and receive a new AWS API URL for each partNumber. Please see AWS’s REST documentation on "PUT Object to S3" on how to upload. Once all parts has been uploaded, proceed to /finish endpoint. Note: nextPartNumber seems like it is always ignored. Despite it returning 0, first partNumber is always 1.
submit_content_agreement
Returns the agreement of the currently authenticated user for the given agreementCode, contentId, and version.
update_asset_review_notes
Update notes regarding an asset review.
upload_gallery_image
Upload a gallery image
upload_icon
Upload an icon
upload_image
Upload an image, which can be an icon, gallery image, sticker or emoji