Module groups_api

Module groups_api 

Enums

AddGroupGalleryImageError
struct for typed errors of method add_group_gallery_image
AddGroupMemberRoleError
struct for typed errors of method add_group_member_role
AddGroupPostError
struct for typed errors of method add_group_post
BanGroupMemberError
struct for typed errors of method ban_group_member
BlockGroupError
struct for typed errors of method block_group
CancelGroupRequestError
struct for typed errors of method cancel_group_request
CancelGroupTransferError
struct for typed errors of method cancel_group_transfer
CreateGroupAnnouncementError
struct for typed errors of method create_group_announcement
CreateGroupError
struct for typed errors of method create_group
CreateGroupGalleryError
struct for typed errors of method create_group_gallery
CreateGroupInviteError
struct for typed errors of method create_group_invite
CreateGroupRoleError
struct for typed errors of method create_group_role
DeclineGroupInviteError
struct for typed errors of method decline_group_invite
DeleteGroupAnnouncementError
struct for typed errors of method delete_group_announcement
DeleteGroupError
struct for typed errors of method delete_group
DeleteGroupGalleryError
struct for typed errors of method delete_group_gallery
DeleteGroupGalleryImageError
struct for typed errors of method delete_group_gallery_image
DeleteGroupInviteError
struct for typed errors of method delete_group_invite
DeleteGroupPostError
struct for typed errors of method delete_group_post
DeleteGroupRoleError
struct for typed errors of method delete_group_role
GetGroupAnnouncementsError
struct for typed errors of method get_group_announcements
GetGroupAuditLogEntryTypesError
struct for typed errors of method get_group_audit_log_entry_types
GetGroupAuditLogsError
struct for typed errors of method get_group_audit_logs
GetGroupBansError
struct for typed errors of method get_group_bans
GetGroupError
struct for typed errors of method get_group
GetGroupGalleryImagesError
struct for typed errors of method get_group_gallery_images
GetGroupInstancesError
struct for typed errors of method get_group_instances
GetGroupInvitesError
struct for typed errors of method get_group_invites
GetGroupMemberError
struct for typed errors of method get_group_member
GetGroupMembersError
struct for typed errors of method get_group_members
GetGroupPermissionsError
struct for typed errors of method get_group_permissions
GetGroupPostsError
struct for typed errors of method get_group_posts
GetGroupRequestsError
struct for typed errors of method get_group_requests
GetGroupRoleTemplatesError
struct for typed errors of method get_group_role_templates
GetGroupRolesError
struct for typed errors of method get_group_roles
GetGroupTransferabilityError
struct for typed errors of method get_group_transferability
InitiateOrAcceptGroupTransferError
struct for typed errors of method initiate_or_accept_group_transfer
JoinGroupError
struct for typed errors of method join_group
KickGroupMemberError
struct for typed errors of method kick_group_member
LeaveGroupError
struct for typed errors of method leave_group
RemoveGroupMemberRoleError
struct for typed errors of method remove_group_member_role
RespondGroupJoinRequestError
struct for typed errors of method respond_group_join_request
SearchGroupMembersError
struct for typed errors of method search_group_members
SearchGroupsError
struct for typed errors of method search_groups
UnbanGroupMemberError
struct for typed errors of method unban_group_member
UpdateGroupError
struct for typed errors of method update_group
UpdateGroupGalleryError
struct for typed errors of method update_group_gallery
UpdateGroupMemberError
struct for typed errors of method update_group_member
UpdateGroupPostError
struct for typed errors of method update_group_post
UpdateGroupRepresentationError
struct for typed errors of method update_group_representation
UpdateGroupRoleError
struct for typed errors of method update_group_role

Functions

add_group_gallery_image
Adds an image to a Group gallery.
add_group_member_role
Adds a Role to a Group Member
add_group_post
Create a post in a Group.
ban_group_member
Bans a user from a Group.
block_group
Blocks a Group for the current user. To unblock a group, call kickGroupMember (DELETE /groups/{groupId}/members/{userId}).
cancel_group_request
Cancels a request sent to join the group.
cancel_group_transfer
Cancel a Group Transfer.
create_group
Creates a Group and returns a Group object. Requires VRC+ Subscription.
create_group_announcement
Creates an Announcement for a Group. Warning: This will also remove all announcements. To make proper announcements, use the posts endpoint instead
create_group_gallery
Creates a gallery for a Group.
create_group_invite
Sends an invite to a user to join the group.
create_group_role
Create a Group role.
decline_group_invite
Declines an invite to the user from a group.
delete_group
Deletes a Group.
delete_group_announcement
Deletes the announcement for a Group.
delete_group_gallery
Deletes a gallery for a Group.
delete_group_gallery_image
Deletes an image from a Group gallery.
delete_group_invite
Deletes an Group invite sent to a User
delete_group_post
Delete a Group post
delete_group_role
Deletes a Group Role by ID and returns the remaining roles.
get_group
Returns a single Group by ID.
get_group_announcements
Returns the announcement for a Group. If no announcement has been made, then it returns empty object. If an announcement exists, then it will always return all fields except imageId and imageUrl which may be null.
get_group_audit_log_entry_types
Returns a list of audit log entry types for which the group has entries.
get_group_audit_logs
Returns a list of audit logs for a Group.
get_group_bans
Returns a list of banned users for a Group.
get_group_gallery_images
Returns a list of images for a Group gallery.
get_group_instances
Returns a list of group instances
get_group_invites
Returns a list of members that have been invited to the Group.
get_group_member
Returns a GroupMember.
get_group_members
Returns a List of all other Group Members. This endpoint will never return the user calling the endpoint. Information about the user calling the endpoint must be found in the myMember field of the Group object.
get_group_permissions
Returns a List of all possible/available permissions for a Group.
get_group_posts
Get posts from a Group
get_group_requests
Returns a list of members that have requested to join the Group.
get_group_role_templates
Obtain predefined templates for group roles
get_group_roles
Returns a Group Role by ID.
get_group_transferability
Returns the transferability of the group to a given user.
initiate_or_accept_group_transfer
To initiate, must be logged in as the current owner and specify the transferTargetId in the body. To accept, must be logged in as the user targeted by a pending transfer, no body is required.
join_group
Join a Group by ID and returns the member object.
kick_group_member
Kicks a Group Member from the Group. The current user must have the "Remove Group Members" permission. Also used for unblocking groups.
leave_group
Leave a group by ID.
remove_group_member_role
Removes a Role from a Group Member
respond_group_join_request
Responds to a Group Join Request with Accept/Deny
search_group_members
Search for members in the group by displayName.
search_groups
Searches Groups by name or shortCode
unban_group_member
Unbans a user from a Group.
update_group
Updates a Group and returns it.
update_group_gallery
Updates a gallery for a Group.
update_group_member
Updates a Group Member
update_group_post
Edits a Group post
update_group_representation
Updates whether the user is representing the group. When isRepresenting is set to true, this flag will be set to false for all other groups
update_group_role
Updates a group role by ID.