get_group_members

Function get_group_members 

pub async fn get_group_members(
    configuration: &Configuration,
    group_id: &str,
    n: Option<i32>,
    offset: Option<i32>,
    sort: Option<GroupSearchSort>,
    role_id: Option<&str>,
) -> Result<Vec<GroupMember>, Error<GetGroupMembersError>>
Returns a List of all other Group Members. This endpoint will never return the user calling the endpoint. Information about the user calling the endpoint must be found in the myMember field of the Group object.