pub async fn get_own_inventory_item(
configuration: &Configuration,
inventory_item_id: &str,
) -> Result<InventoryItem, Error<GetOwnInventoryItemError>>Expand description
Returns an InventoryItem object held by the currently logged in user.
pub async fn get_own_inventory_item(
configuration: &Configuration,
inventory_item_id: &str,
) -> Result<InventoryItem, Error<GetOwnInventoryItemError>>Returns an InventoryItem object held by the currently logged in user.