pub fn update_invite_message(
    configuration: &Configuration,
    user_id: &str,
    message_type: &str,
    slot: i32,
    update_invite_message_request: Option<UpdateInviteMessageRequest>
) -> Result<Vec<InviteMessage>, Error<UpdateInviteMessageError>>
Updates a single Invite Message and then returns a list of all of them. Admin Credentials are required to update messages of other users! Updating a message automatically sets the cooldown timer to 60 minutes. Trying to edit a message before the cooldown timer expires results in a 429 "Too Fast Error". Message type refers to a different collection of messages, used during different types of responses. * message = Message during a normal invite * response = Message when replying to a message * request = Message when requesting an invite * requestResponse = Message when replying to a request for invite