pub struct AddFavoriteRequest {
    pub type: FavoriteType,
    pub favorite_id: String,
    pub tags: Vec<String>,
}

Fields

type: FavoriteTypefavorite_id: String

Must be either AvatarID, WorldID or UserID.

tags: Vec<String>

Tags indicate which group this favorite belongs to. Adding multiple groups makes it show up in all. Removing it from one in that case removes it from all.

Implementations