Struct vrchatapi::models::notification::Notification
source · pub struct Notification {
pub created_at: String,
pub details: String,
pub id: String,
pub message: String,
pub seen: Option<bool>,
pub receiver_user_id: Option<String>,
pub sender_user_id: String,
pub sender_username: Option<String>,
pub type: NotificationType,
}Expand description
Notification :
Fields
created_at: Stringdetails: StringNOTICE: This is not a JSON object when received from the REST API, but it is when received from the Websocket API. When received from the REST API, this is a json encoded object, meaning you have to json-de-encode to get the NotificationDetail object depending on the NotificationType.
id: Stringmessage: Stringseen: Option<bool>Not included in notification objects received from the Websocket API
receiver_user_id: Option<String>A users unique ID, usually in the form of usr_c1644b5b-3ca4-45b4-97c6-a2a0de70d469. Legacy players can have old IDs in the form of 8JoV9XEdpo. The ID can never be changed.
sender_user_id: StringA users unique ID, usually in the form of usr_c1644b5b-3ca4-45b4-97c6-a2a0de70d469. Legacy players can have old IDs in the form of 8JoV9XEdpo. The ID can never be changed.
sender_username: Option<String>-| DEPRECATED: VRChat API no longer return usernames of other users. See issue by Tupper for more information.
type: NotificationTypeImplementations
sourceimpl Notification
impl Notification
sourcepub fn new(
created_at: String,
details: String,
id: String,
message: String,
sender_user_id: String,
type: NotificationType
) -> Notification
pub fn new( created_at: String, details: String, id: String, message: String, sender_user_id: String, type: NotificationType ) -> Notification