pub struct PermissionData {
pub badges: Option<Vec<String>>,
pub max: Option<i32>,
pub max_favorite_groups: Option<HashMap<String, i32>>,
pub max_favorites_per_group: Option<HashMap<String, i32>>,
pub tags: Option<Vec<String>>,
}Expand description
PermissionData : Specific values afforded the user by this permission
Fields
badges: Option<Vec<String>>Badges afforded the user by this permission
max: Option<i32>Maximum value afforded the user by this permission
max_favorite_groups: Option<HashMap<String, i32>>Maximum favorite groups afforded the user by this permission
max_favorites_per_group: Option<HashMap<String, i32>>Maximum favorites per group afforded the user by this permission
Tags afforded the user by this permission
Implementations
Sourceimpl PermissionData
impl PermissionData
Sourcepub fn new() -> PermissionData
pub fn new() -> PermissionData
Specific values afforded the user by this permission