SubmitModerationReportRequestDetails

Struct SubmitModerationReportRequestDetails 

pub struct SubmitModerationReportRequestDetails {
    pub file_id: Option<String>,
    pub holder_id: Option<String>,
    pub image_type: Option<String>,
    pub instance_age_gated: Option<bool>,
    pub instance_type: Option<String>,
    pub suggested_warnings: Option<Vec<ContentFilter>>,
    pub user_in_same_instance: Option<bool>,
}
SubmitModerationReportRequestDetails : Relevant details specific to the type of the report. fileId is for the image file attached to an inventory item, such as an emoji. holderId is for the user who owns an inventory item, such as a emoji.

Fields

file_id: Option<String>holder_id: Option<String>

A users unique ID, usually in the form of usr_c1644b5b-3ca4-45b4-97c6-a2a0de70d469. Legacy players can have old IDs in the form of 8JoV9XEdpo. The ID can never be changed.

image_type: Option<String>

Relevant detail for reports about image content, such as emoji.

instance_age_gated: Option<bool>

Relevant detail for reports taking place from within an instance.

instance_type: Option<String>

Relevant detail for reports taking place from within an instance.

suggested_warnings: Option<Vec<ContentFilter>>

Relevant detail for reports about content that might not be tagged properly.

user_in_same_instance: Option<bool>

Relevant detail for reports involving another user in the same instance world.

Implementations

Source

impl SubmitModerationReportRequestDetails

pub fn new() -> SubmitModerationReportRequestDetails

Relevant details specific to the type of the report. fileId is for the image file attached to an inventory item, such as an emoji. holderId is for the user who owns an inventory item, such as a emoji.