Module vrchatapi::apis::files_api[][src]

Enums

struct for typed errors of method create_file

struct for typed errors of method create_file_version

struct for typed errors of method delete_file

struct for typed errors of method delete_file_version

struct for typed errors of method download_file_version

struct for typed errors of method finish_file_data_upload

struct for typed errors of method get_file

struct for typed errors of method get_files

struct for typed errors of method start_file_data_upload

Functions

Creates a new File object

Creates a new FileVersion. Once a Version has been created, proceed to the /file/{fileId}/{versionId}/file/start endpoint to start a file upload.

Deletes a File object.

Delete a specific version of a file. You can only delete the latest version.

Downloads the file with the provided version number. Version Note: Version 0 is always when the file was created. The real data is usually always located in version 1 and up. Extension Note: Files are not guaranteed to have a file extensions. UnityPackage files tends to have it, images through this endpoint do not. You are responsible for appending file extension from the extension field when neccesary.

Finish an upload of a FileData. This will mark it as "complete". After uploading the file for Avatars and Worlds you then have to upload a signature file.

Shows general information about the "File" object. Each File can have several "Version"’s, and each Version can have multiple real files or "Data" blobs.

Retrieves the upload status for file upload. Can currently only be accessed when status is waiting. Trying to access it on a file version already uploaded currently times out.

Returns a list of files

Starts an upload of a specific FilePart. This endpoint will return an AWS URL which you can PUT data to. You need to call this and receive a new AWS API URL for each partNumber. Please see AWS’s REST documentation on "PUT Object to S3" on how to upload. Once all parts has been uploaded, proceed to /finish endpoint. Note: nextPartNumber seems like it is always ignored. Despite it returning 0, first partNumber is always 1.