Module vrchatapi::apis::permissions_api
source · [−]Enums
struct for typed errors of method get_assigned_permissions
struct for typed errors of method get_permission
Functions
Returns a list of all permissions currently granted by the user. Permissions are assigned e.g. by subscribing to VRC+.
Returns a single permission. This endpoint is pretty useless, as it returns the exact same information as /auth/permissions.