Struct vrchatapi::models::add_favorite_request::AddFavoriteRequest
source · pub struct AddFavoriteRequest {
pub type: FavoriteType,
pub favorite_id: String,
pub tags: Vec<String>,
}Fields
type: FavoriteTypefavorite_id: StringMust be either AvatarID, WorldID or UserID.
Tags indicate which group this favorite belongs to. Adding multiple groups makes it show up in all. Removing it from one in that case removes it from all.
Implementations
sourceimpl AddFavoriteRequest
impl AddFavoriteRequest
pub fn new( type: FavoriteType, favorite_id: String, tags: Vec<String> ) -> AddFavoriteRequest