pub struct ApiConfig {Show 126 fields
pub campaign_status: String,
pub disable_background_preloads: bool,
pub location_gifting_non_sub_prio_enabled: bool,
pub voice_enable_degradation: bool,
pub voice_enable_receiver_limiting: bool,
pub access_logs_urls: ApiConfigAccessLogsUrls,
pub address: String,
pub age_verification_invite_visible: bool,
pub age_verification_p: bool,
pub age_verification_status_visible: bool,
pub analysis_max_retries: i32,
pub analysis_retry_interval: i32,
pub analytics_segment_new_ui_pct_of_users: i32,
pub analytics_segment_new_ui_salt: String,
pub announcements: Vec<ApiConfigAnnouncement>,
pub audio_config: Option<ApiConfigAudioConfig>,
pub available_language_codes: Vec<String>,
pub available_languages: Vec<String>,
pub avatar_perf_limiter: ApiConfigAvatarPerfLimiter,
pub chatbox_log_buffer_seconds: i32,
pub client_api_key: String,
pub client_bps_ceiling: i32,
pub client_disconnect_timeout: i32,
pub client_net_dispatch_thread: Option<bool>,
pub client_net_dispatch_thread_mobile: bool,
pub client_net_in_thread: Option<bool>,
pub client_net_in_thread2: Option<bool>,
pub client_net_in_thread_mobile: Option<bool>,
pub client_net_in_thread_mobile2: Option<bool>,
pub client_net_out_thread: Option<bool>,
pub client_net_out_thread2: Option<bool>,
pub client_net_out_thread_mobile: Option<bool>,
pub client_net_out_thread_mobile2: Option<bool>,
pub client_qr: Option<i32>,
pub client_reserved_player_bps: i32,
pub client_sent_count_allowance: i32,
pub constants: ApiConfigConstants,
pub contact_email: String,
pub copyright_email: String,
pub copyright_form_url: String,
pub current_privacy_version: i32,
pub current_tos_version: i32,
pub default_avatar: String,
pub default_sticker_set: String,
pub dev_language_codes: Option<Vec<String>>,
pub dev_sdk_url: String,
pub dev_sdk_version: String,
pub dis_countdown: String,
pub disable_av_pro_in_proton: Option<bool>,
pub disable_avatar_copying: bool,
pub disable_avatar_gating: bool,
pub disable_captcha: Option<bool>,
pub disable_community_labs: bool,
pub disable_community_labs_promotion: bool,
pub disable_email: bool,
pub disable_event_stream: bool,
pub disable_feedback_gating: bool,
pub disable_frontend_builds: bool,
pub disable_gift_drops: bool,
pub disable_hello: bool,
pub disable_oculus_subs: bool,
pub disable_registration: bool,
pub disable_steam_networking: bool,
pub disable_two_factor_auth: bool,
pub disable_udon: bool,
pub disable_upgrade_account: bool,
pub download_link_windows: String,
pub download_urls: ApiConfigDownloadUrlList,
pub dynamic_world_rows: Vec<DynamicContentRow>,
pub economy_ledger_backfill: bool,
pub economy_ledger_migration_stop: String,
pub economy_ledger_mode: String,
pub economy_pause_end: String,
pub economy_pause_start: String,
pub economy_purchase_repair_enabled: bool,
pub economy_state: i32,
pub events: ApiConfigEvents,
pub force_use_latest_world: bool,
pub gift_display_type: String,
pub google_api_client_id: String,
pub home_world_id: String,
pub homepage_redirect_target: String,
pub hub_world_id: String,
pub image_host_url_list: Vec<String>,
pub ios_app_version: Vec<String>,
pub ios_version: ApiConfigIosVersion,
pub jobs_email: String,
pub max_user_emoji: i32,
pub max_user_stickers: i32,
pub min_supported_client_build_number: ApiConfigMinSupportedClientBuildNumber,
pub minimum_unity_version_for_uploads: String,
pub moderation_email: String,
pub not_allowed_to_select_avatar_in_private_world_message: String,
pub offline_analysis: ApiConfigOfflineAnalysis,
pub photon_nameserver_overrides: Vec<String>,
pub photon_public_keys: Vec<String>,
pub player_url_resolver_sha1: String,
pub player_url_resolver_version: String,
pub public_key: String,
pub report_categories: HashMap<String, ReportCategory>,
pub report_form_url: String,
pub report_options: HashMap<String, HashMap<String, Vec<String>>>,
pub report_reasons: HashMap<String, ReportReason>,
pub require_age_verification_beta_tag: bool,
pub sdk_developer_faq_url: String,
pub sdk_discord_url: String,
pub sdk_not_allowed_to_publish_message: String,
pub sdk_unity_version: String,
pub string_host_url_list: Vec<String>,
pub support_email: String,
pub support_form_url: String,
pub time_out_world_id: String,
pub timekeeping: bool,
pub tutorial_world_id: String,
pub update_rate_ms_maximum: i32,
pub update_rate_ms_minimum: i32,
pub update_rate_ms_normal: i32,
pub update_rate_ms_udon_manual: i32,
pub upload_analysis_percent: i32,
pub url_list: Vec<String>,
pub use_reliable_udp_for_voice: bool,
pub vive_windows_url: String,
pub websocket_max_friends_refresh_delay: i32,
pub websocket_quick_reconnect_time: i32,
pub websocket_reconnect_max_delay: i32,
pub white_listed_asset_urls: Vec<String>,
}Expand description
ApiConfig : Global configuration for various features.
Fields
campaign_status: StringThe current platform-wide event taking place
disable_background_preloads: boolToggles if certain assets are preloaded in the background
location_gifting_non_sub_prio_enabled: boolToggles whether users without a current VRC+ subscription are priority recipients for gift drops
voice_enable_degradation: boolUnknown, probably voice optimization testing
voice_enable_receiver_limiting: boolUnknown, probably voice optimization testing
access_logs_urls: ApiConfigAccessLogsUrlsaddress: StringVRChat’s office address
age_verification_invite_visible: boolage_verification_p: boolage_verification_status_visible: boolanalysis_max_retries: i32Max retries for avatar analysis requests
analysis_retry_interval: i32Interval between retries for avatar analysis requests
analytics_segment_new_ui_pct_of_users: i32Unknown
analytics_segment_new_ui_salt: StringUnknown
announcements: Vec<ApiConfigAnnouncement>Public Announcements
audio_config: Option<ApiConfigAudioConfig>available_language_codes: Vec<String>List of supported Languages
available_languages: Vec<String>List of supported Languages
avatar_perf_limiter: ApiConfigAvatarPerfLimiterchatbox_log_buffer_seconds: i32Unknown
client_api_key: StringapiKey to be used for all other requests
client_bps_ceiling: i32Unknown
client_disconnect_timeout: i32Unknown
client_net_dispatch_thread: Option<bool>Unknown
client_net_dispatch_thread_mobile: boolUnknown
client_net_in_thread: Option<bool>Unknown
client_net_in_thread2: Option<bool>Unknown
client_net_in_thread_mobile: Option<bool>Unknown
client_net_in_thread_mobile2: Option<bool>Unknown
client_net_out_thread: Option<bool>Unknown
client_net_out_thread2: Option<bool>Unknown
client_net_out_thread_mobile: Option<bool>Unknown
client_net_out_thread_mobile2: Option<bool>Unknown
client_qr: Option<i32>Unknown
client_reserved_player_bps: i32Unknown
client_sent_count_allowance: i32Unknown
constants: ApiConfigConstantscontact_email: StringVRChat’s contact email
copyright_email: StringVRChat’s copyright-issues-related email
copyright_form_url: StringVRChat’s DMCA claim webform url
current_privacy_version: i32Current version number of the Privacy Agreement
current_tos_version: i32Current version number of the Terms of Service
default_avatar: Stringdefault_sticker_set: Stringdev_language_codes: Option<Vec<String>>Unknown
dev_sdk_url: StringLink to download the development SDK, use downloadUrls instead
dev_sdk_version: StringVersion of the development SDK
dis_countdown: StringUnknown, "dis" maybe for disconnect?
disable_av_pro_in_proton: Option<bool>Unknown
disable_avatar_copying: boolToggles if copying avatars should be disabled
disable_avatar_gating: boolToggles if avatar gating should be disabled. Avatar gating restricts uploading of avatars to people with the system_avatar_access Tag or admin_avatar_access Tag
disable_captcha: Option<bool>Unknown
disable_community_labs: boolToggles if the Community Labs should be disabled
disable_community_labs_promotion: boolToggles if promotion out of Community Labs should be disabled
disable_email: boolUnknown
disable_event_stream: boolToggles if Analytics should be disabled.
disable_feedback_gating: boolToggles if feedback gating should be disabled. Feedback gating restricts submission of feedback (reporting a World or User) to people with the system_feedback_access Tag.
disable_frontend_builds: boolUnknown, probably toggles compilation of frontend web builds? So internal flag?
disable_gift_drops: boolToggles if gift drops should be disabled
disable_hello: boolUnknown
disable_oculus_subs: boolToggles if signing up for Subscriptions in Oculus is disabled or not.
disable_registration: boolToggles if new user account registration should be disabled.
disable_steam_networking: boolToggles if Steam Networking should be disabled. VRChat these days uses Photon Unity Networking (PUN) instead.
disable_two_factor_auth: boolToggles if 2FA should be disabled.
disable_udon: boolToggles if Udon should be universally disabled in-game.
disable_upgrade_account: boolToggles if account upgrading "linking with Steam/Oculus" should be disabled.
download_link_windows: StringDownload link for game on the Oculus Rift website.
download_urls: ApiConfigDownloadUrlListdynamic_world_rows: Vec<DynamicContentRow>Array of DynamicWorldRow objects, used by the game to display the list of world rows
economy_ledger_backfill: boolUnknown
economy_ledger_migration_stop: StringUnknown
economy_ledger_mode: StringUnknown
economy_pause_end: StringUnknown
economy_pause_start: StringUnknown
economy_purchase_repair_enabled: boolUnknown
economy_state: i32Unknown
events: ApiConfigEventsforce_use_latest_world: boolUnknown
gift_display_type: StringDisplay type of gifts
google_api_client_id: StringUnknown
home_world_id: StringWorldID be "offline" on User profiles if you are not friends with that user.
homepage_redirect_target: StringRedirect target if you try to open the base API domain in your browser
hub_world_id: StringWorldID be "offline" on User profiles if you are not friends with that user.
image_host_url_list: Vec<String>A list of explicitly allowed origins that worlds can request images from via the Udon’s VRCImageDownloader#DownloadImage.
ios_app_version: Vec<String>Current app version for iOS
ios_version: ApiConfigIosVersionjobs_email: StringVRChat’s job application email
max_user_emoji: i32The maximum number of custom emoji each user may have at a given time.
max_user_stickers: i32The maximum number of custom stickers each user may have at a given time.
min_supported_client_build_number: ApiConfigMinSupportedClientBuildNumberminimum_unity_version_for_uploads: StringMinimum Unity version required for uploading assets
moderation_email: StringVRChat’s moderation related email
not_allowed_to_select_avatar_in_private_world_message: StringUsed in-game to notify a user they aren’t allowed to select avatars in private worlds
offline_analysis: ApiConfigOfflineAnalysisphoton_nameserver_overrides: Vec<String>Unknown
photon_public_keys: Vec<String>Unknown
player_url_resolver_sha1: StringCurrently used youtube-dl.exe hash in SHA1-delimited format
player_url_resolver_version: StringCurrently used youtube-dl.exe version
public_key: StringPublic key, hex encoded
report_categories: HashMap<String, ReportCategory>Categories available for reporting objectionable content
report_form_url: StringURL to the report form
report_options: HashMap<String, HashMap<String, Vec<String>>>Options for reporting content. Select a key+value from this mapping as the type of the report. Select one key+value from the object at reportOptions[type] as the category of the report. reportCategories[category] contains user-facing text to display for all possible categories. Select one value from the array at reportOptions[type][category] as the reason of the report. reportReasons[reason] contains user-facing text to display for all possible categories.
report_reasons: HashMap<String, ReportReason>Reasons available for submitting a report
require_age_verification_beta_tag: boolsdk_developer_faq_url: StringLink to the developer FAQ
sdk_discord_url: StringLink to the official VRChat Discord
sdk_not_allowed_to_publish_message: StringUsed in the SDK to notify a user they aren’t allowed to upload avatars/worlds yet
sdk_unity_version: StringUnity version supported by the SDK
string_host_url_list: Vec<String>A list of explicitly allowed origins that worlds can request strings from via the Udon’s VRCStringDownloader.LoadUrl.
support_email: StringVRChat’s support email
support_form_url: StringVRChat’s support form
time_out_world_id: StringWorldID be "offline" on User profiles if you are not friends with that user.
timekeeping: boolUnknown
tutorial_world_id: StringWorldID be "offline" on User profiles if you are not friends with that user.
update_rate_ms_maximum: i32Unknown
update_rate_ms_minimum: i32Unknown
update_rate_ms_normal: i32Unknown
update_rate_ms_udon_manual: i32Unknown
upload_analysis_percent: i32Unknown
url_list: Vec<String>List of allowed URLs that bypass the "Allow untrusted URL’s" setting in-game
use_reliable_udp_for_voice: boolUnknown
vive_windows_url: StringDownload link for game on the Steam website.
websocket_max_friends_refresh_delay: i32Unknown
websocket_quick_reconnect_time: i32Unknown
websocket_reconnect_max_delay: i32Unknown
white_listed_asset_urls: Vec<String>List of allowed URLs that are allowed to host avatar assets
Implementations
Sourceimpl ApiConfig
impl ApiConfig
Sourcepub fn new(
campaign_status: String,
disable_background_preloads: bool,
location_gifting_non_sub_prio_enabled: bool,
voice_enable_degradation: bool,
voice_enable_receiver_limiting: bool,
access_logs_urls: ApiConfigAccessLogsUrls,
address: String,
age_verification_invite_visible: bool,
age_verification_p: bool,
age_verification_status_visible: bool,
analysis_max_retries: i32,
analysis_retry_interval: i32,
analytics_segment_new_ui_pct_of_users: i32,
analytics_segment_new_ui_salt: String,
announcements: Vec<ApiConfigAnnouncement>,
available_language_codes: Vec<String>,
available_languages: Vec<String>,
avatar_perf_limiter: ApiConfigAvatarPerfLimiter,
chatbox_log_buffer_seconds: i32,
client_api_key: String,
client_bps_ceiling: i32,
client_disconnect_timeout: i32,
client_net_dispatch_thread_mobile: bool,
client_reserved_player_bps: i32,
client_sent_count_allowance: i32,
constants: ApiConfigConstants,
contact_email: String,
copyright_email: String,
copyright_form_url: String,
current_privacy_version: i32,
current_tos_version: i32,
default_avatar: String,
default_sticker_set: String,
dev_sdk_url: String,
dev_sdk_version: String,
dis_countdown: String,
disable_avatar_copying: bool,
disable_avatar_gating: bool,
disable_community_labs: bool,
disable_community_labs_promotion: bool,
disable_email: bool,
disable_event_stream: bool,
disable_feedback_gating: bool,
disable_frontend_builds: bool,
disable_gift_drops: bool,
disable_hello: bool,
disable_oculus_subs: bool,
disable_registration: bool,
disable_steam_networking: bool,
disable_two_factor_auth: bool,
disable_udon: bool,
disable_upgrade_account: bool,
download_link_windows: String,
download_urls: ApiConfigDownloadUrlList,
dynamic_world_rows: Vec<DynamicContentRow>,
economy_ledger_backfill: bool,
economy_ledger_migration_stop: String,
economy_ledger_mode: String,
economy_pause_end: String,
economy_pause_start: String,
economy_purchase_repair_enabled: bool,
economy_state: i32,
events: ApiConfigEvents,
force_use_latest_world: bool,
gift_display_type: String,
google_api_client_id: String,
home_world_id: String,
homepage_redirect_target: String,
hub_world_id: String,
image_host_url_list: Vec<String>,
ios_app_version: Vec<String>,
ios_version: ApiConfigIosVersion,
jobs_email: String,
max_user_emoji: i32,
max_user_stickers: i32,
min_supported_client_build_number: ApiConfigMinSupportedClientBuildNumber,
minimum_unity_version_for_uploads: String,
moderation_email: String,
not_allowed_to_select_avatar_in_private_world_message: String,
offline_analysis: ApiConfigOfflineAnalysis,
photon_nameserver_overrides: Vec<String>,
photon_public_keys: Vec<String>,
player_url_resolver_sha1: String,
player_url_resolver_version: String,
public_key: String,
report_categories: HashMap<String, ReportCategory>,
report_form_url: String,
report_options: HashMap<String, HashMap<String, Vec<String>>>,
report_reasons: HashMap<String, ReportReason>,
require_age_verification_beta_tag: bool,
sdk_developer_faq_url: String,
sdk_discord_url: String,
sdk_not_allowed_to_publish_message: String,
sdk_unity_version: String,
string_host_url_list: Vec<String>,
support_email: String,
support_form_url: String,
time_out_world_id: String,
timekeeping: bool,
tutorial_world_id: String,
update_rate_ms_maximum: i32,
update_rate_ms_minimum: i32,
update_rate_ms_normal: i32,
update_rate_ms_udon_manual: i32,
upload_analysis_percent: i32,
url_list: Vec<String>,
use_reliable_udp_for_voice: bool,
vive_windows_url: String,
websocket_max_friends_refresh_delay: i32,
websocket_quick_reconnect_time: i32,
websocket_reconnect_max_delay: i32,
white_listed_asset_urls: Vec<String>,
) -> ApiConfig
pub fn new( campaign_status: String, disable_background_preloads: bool, location_gifting_non_sub_prio_enabled: bool, voice_enable_degradation: bool, voice_enable_receiver_limiting: bool, access_logs_urls: ApiConfigAccessLogsUrls, address: String, age_verification_invite_visible: bool, age_verification_p: bool, age_verification_status_visible: bool, analysis_max_retries: i32, analysis_retry_interval: i32, analytics_segment_new_ui_pct_of_users: i32, analytics_segment_new_ui_salt: String, announcements: Vec<ApiConfigAnnouncement>, available_language_codes: Vec<String>, available_languages: Vec<String>, avatar_perf_limiter: ApiConfigAvatarPerfLimiter, chatbox_log_buffer_seconds: i32, client_api_key: String, client_bps_ceiling: i32, client_disconnect_timeout: i32, client_net_dispatch_thread_mobile: bool, client_reserved_player_bps: i32, client_sent_count_allowance: i32, constants: ApiConfigConstants, contact_email: String, copyright_email: String, copyright_form_url: String, current_privacy_version: i32, current_tos_version: i32, default_avatar: String, default_sticker_set: String, dev_sdk_url: String, dev_sdk_version: String, dis_countdown: String, disable_avatar_copying: bool, disable_avatar_gating: bool, disable_community_labs: bool, disable_community_labs_promotion: bool, disable_email: bool, disable_event_stream: bool, disable_feedback_gating: bool, disable_frontend_builds: bool, disable_gift_drops: bool, disable_hello: bool, disable_oculus_subs: bool, disable_registration: bool, disable_steam_networking: bool, disable_two_factor_auth: bool, disable_udon: bool, disable_upgrade_account: bool, download_link_windows: String, download_urls: ApiConfigDownloadUrlList, dynamic_world_rows: Vec<DynamicContentRow>, economy_ledger_backfill: bool, economy_ledger_migration_stop: String, economy_ledger_mode: String, economy_pause_end: String, economy_pause_start: String, economy_purchase_repair_enabled: bool, economy_state: i32, events: ApiConfigEvents, force_use_latest_world: bool, gift_display_type: String, google_api_client_id: String, home_world_id: String, homepage_redirect_target: String, hub_world_id: String, image_host_url_list: Vec<String>, ios_app_version: Vec<String>, ios_version: ApiConfigIosVersion, jobs_email: String, max_user_emoji: i32, max_user_stickers: i32, min_supported_client_build_number: ApiConfigMinSupportedClientBuildNumber, minimum_unity_version_for_uploads: String, moderation_email: String, not_allowed_to_select_avatar_in_private_world_message: String, offline_analysis: ApiConfigOfflineAnalysis, photon_nameserver_overrides: Vec<String>, photon_public_keys: Vec<String>, player_url_resolver_sha1: String, player_url_resolver_version: String, public_key: String, report_categories: HashMap<String, ReportCategory>, report_form_url: String, report_options: HashMap<String, HashMap<String, Vec<String>>>, report_reasons: HashMap<String, ReportReason>, require_age_verification_beta_tag: bool, sdk_developer_faq_url: String, sdk_discord_url: String, sdk_not_allowed_to_publish_message: String, sdk_unity_version: String, string_host_url_list: Vec<String>, support_email: String, support_form_url: String, time_out_world_id: String, timekeeping: bool, tutorial_world_id: String, update_rate_ms_maximum: i32, update_rate_ms_minimum: i32, update_rate_ms_normal: i32, update_rate_ms_udon_manual: i32, upload_analysis_percent: i32, url_list: Vec<String>, use_reliable_udp_for_voice: bool, vive_windows_url: String, websocket_max_friends_refresh_delay: i32, websocket_quick_reconnect_time: i32, websocket_reconnect_max_delay: i32, white_listed_asset_urls: Vec<String>, ) -> ApiConfig
Global configuration for various features.