pub struct Instance {Show 23 fields
pub active: bool,
pub can_request_invite: bool,
pub capacity: i32,
pub client_number: String,
pub full: bool,
pub id: String,
pub instance_id: String,
pub location: String,
pub n_users: i32,
pub name: String,
pub owner_id: Option<String>,
pub permanent: bool,
pub photon_region: Region,
pub platforms: Box<InstancePlatforms>,
pub region: Region,
pub secure_name: String,
pub short_name: Option<String>,
pub tags: Vec<String>,
pub type: InstanceType,
pub world_id: String,
pub hidden: Option<String>,
pub friends: Option<String>,
pub private: Option<String>,
}Expand description
Instance : * hidden field is only present if InstanceType is hidden aka "Friends+", and is instance creator. * friends field is only present if InstanceType is friends aka "Friends", and is instance creator. * private field is only present if InstanceType is private aka "Invite" or "Invite+", and is instance creator.
Fields
active: boolcan_request_invite: boolcapacity: i32client_number: StringAlways returns "unknown".
full: boolid: StringInstanceID can be "offline" on User profiles if you are not friends with that user and "private" if you are friends and user is in private instance.
instance_id: Stringlocation: StringInstanceID can be "offline" on User profiles if you are not friends with that user and "private" if you are friends and user is in private instance.
n_users: i32name: Stringowner_id: Option<String>A users unique ID, usually in the form of usr_c1644b5b-3ca4-45b4-97c6-a2a0de70d469. Legacy players can have old IDs in the form of 8JoV9XEdpo. The ID can never be changed.
permanent: boolphoton_region: Regionplatforms: Box<InstancePlatforms>region: Regionsecure_name: Stringshort_name: Option<String>The tags array on Instances usually contain the language tags of the people in the instance.
type: InstanceTypeworld_id: StringWorldID be "offline" on User profiles if you are not friends with that user.
A users unique ID, usually in the form of usr_c1644b5b-3ca4-45b4-97c6-a2a0de70d469. Legacy players can have old IDs in the form of 8JoV9XEdpo. The ID can never be changed.
friends: Option<String>A users unique ID, usually in the form of usr_c1644b5b-3ca4-45b4-97c6-a2a0de70d469. Legacy players can have old IDs in the form of 8JoV9XEdpo. The ID can never be changed.
private: Option<String>A users unique ID, usually in the form of usr_c1644b5b-3ca4-45b4-97c6-a2a0de70d469. Legacy players can have old IDs in the form of 8JoV9XEdpo. The ID can never be changed.
Implementations
sourceimpl Instance
impl Instance
sourcepub fn new(
active: bool,
can_request_invite: bool,
capacity: i32,
client_number: String,
full: bool,
id: String,
instance_id: String,
location: String,
n_users: i32,
name: String,
permanent: bool,
photon_region: Region,
platforms: InstancePlatforms,
region: Region,
secure_name: String,
tags: Vec<String>,
type: InstanceType,
world_id: String
) -> Instance
pub fn new( active: bool, can_request_invite: bool, capacity: i32, client_number: String, full: bool, id: String, instance_id: String, location: String, n_users: i32, name: String, permanent: bool, photon_region: Region, platforms: InstancePlatforms, region: Region, secure_name: String, tags: Vec<String>, type: InstanceType, world_id: String ) -> Instance
hiddenfield is only present if InstanceType ishiddenaka "Friends+", and is instance creator. *friendsfield is only present if InstanceType isfriendsaka "Friends", and is instance creator. *privatefield is only present if InstanceType isprivateaka "Invite" or "Invite+", and is instance creator.